@@ -26,7 +26,7 @@ function(delta)
 
     if(k.beta == 1) {
 
-      eta.mu <- X * delta[1]
+      eta.mu <- Xsave * delta[1]
 
     }
 
@@ -34,15 +34,15 @@ function(delta)
 
       beta <- delta[1:k.beta]
 
-      eta.mu <- X %*% beta
+      eta.mu <- Xsave %*% beta
 
     }
 
-  if(is.null(W)==FALSE){
+  if(is.null(Wsave)==FALSE){
 
     if(k.alpha == 1) {
 
-      eta.phi <- W * delta[k.beta + 1]
+      eta.phi <- Wsave * delta[k.beta + 1]
 
     }
 
@@ -50,17 +50,17 @@ function(delta)
 
       alpha <- delta[(k.beta + 1) : (k.beta + k.alpha)]
 
-      eta.phi <- W %*% alpha
+      eta.phi <- Wsave %*% alpha
 
     }
 
   }
 
-  if(is.null(Z)==FALSE){
+  if(is.null(Zsave)==FALSE){
 
     if(k.gamma == 1) {
 
-      eta.omega <- Z * delta[k.beta + k.alpha + 1]
+      eta.omega <- Zsave * delta[k.beta + k.alpha + 1]
 
     }
 
@@ -68,7 +68,7 @@ function(delta)
 
       gamma <- delta[(k.beta + k.alpha + 1) : (k.beta + k.alpha + k.gamma)]
 
-      eta.omega <- Z %*% gamma
+      eta.omega <- Zsave %*% gamma
 
     }
 
@@ -78,7 +78,7 @@ function(delta)
 
     mu.i <- t.i*exp(eta.mu)
 
-    if(is.null(Z)==FALSE) {
+    if(is.null(Zsave)==FALSE) {
 
       k.i <- exp(eta.omega)
 
@@ -86,7 +86,7 @@ function(delta)
     
     else { k.i <- rep(0,n) }
 
-    if(is.null(W)==FALSE) {
+    if(is.null(Wsave)==FALSE) {
 
       b.i <- exp(eta.phi)
 
@@ -100,11 +100,11 @@ function(delta)
 
     P0 <- exp(-1/phi.i*mu.i)
 
-if(k.beta==1){ X <- cbind(X,rep(0,length(X)))  }
+if(k.beta==1){ Xsave <- cbind(Xsave,rep(0,length(Xsave)))  }
 
-if(k.alpha==1){ W <- cbind(W,rep(0,length(W)))  }
+if(k.alpha==1){ Wsave <- cbind(Wsave,rep(0,length(Wsave)))  }
 
-if(k.gamma==1){ Z <- cbind(Z,rep(0,length(Z)))  }
+if(k.gamma==1){ Zsave <- cbind(Zsave,rep(0,length(Zsave)))  }
 
 
 # Derivative for beta
@@ -115,11 +115,11 @@ for (j in 1:k.beta)
 
 # terms of gradient with 1_{Y_i = 0}
 
-    s1 <- sum(ifelse(Y == 0,1,0)* X[,j]*(P0*(-1/phi.i)*mu.i/(k.i+P0)))
+    s1 <- sum(ifelse(Y == 0,1,0)* Xsave[,j]*(P0*(-1/phi.i)*mu.i/(k.i+P0)))
 
 # terms of gradient with 1_{Y_i > 0}
 
-    s2 <- sum(ifelse(Y>0,1,0)* X[,j]*(1+(Y-1)*mu.i/(mu.i+b.i*Y)-1/phi.i*mu.i))
+    s2 <- sum(ifelse(Y>0,1,0)* Xsave[,j]*(1+(Y-1)*mu.i/(mu.i+b.i*Y)-1/phi.i*mu.i))
 
   grad[j] <- s1 + s2
 
@@ -131,7 +131,7 @@ for (j in 1:k.beta)
 
 # Derivative for alpha
 
-if(is.null(W)==FALSE) {
+if(is.null(Wsave)==FALSE) {
 
   for (j in 1:k.alpha)
 
@@ -139,11 +139,11 @@ if(is.null(W)==FALSE) {
 
   # terms of gradient with 1_{Y_i = 0}
 
-      s1 <- sum(ifelse(Y == 0,1,0)*W[,j]*b.i*(1/phi.i^2*P0*mu.i/(k.i+P0)))
+      s1 <- sum(ifelse(Y == 0,1,0)*Wsave[,j]*b.i*(1/phi.i^2*P0*mu.i/(k.i+P0)))
 
   # terms of gradient with 1_{Y_i > 0}
 
-      s2 <- sum(ifelse(Y>0,1,0)*W[,j]*b.i*(Y*(Y-1)/(mu.i + b.i*Y)-Y/phi.i+(mu.i-Y)/phi.i^2))
+      s2 <- sum(ifelse(Y>0,1,0)*Wsave[,j]*b.i*(Y*(Y-1)/(mu.i + b.i*Y)-Y/phi.i+(mu.i-Y)/phi.i^2))
 
     grad[k.beta+j] <- s1 + s2
 
@@ -157,7 +157,7 @@ if(is.null(W)==FALSE) {
 
 # Derivative for gamma
 
-if(is.null(Z)==FALSE) {
+if(is.null(Zsave)==FALSE) {
 
   for (j in 1:k.gamma)
 
@@ -165,11 +165,11 @@ if(is.null(Z)==FALSE) {
 
   # terms of gradient with 1_{Y_i = 0}
 
-      s1 <- sum(ifelse(Y == 0,1,0)* Z[,j]* k.i * (1/(k.i + P0)))
+      s1 <- sum(ifelse(Y == 0,1,0)* Zsave[,j]* k.i * (1/(k.i + P0)))
 
   # terms of gradient independent of Y_i
 
-      s2 <- -sum(Z[,j]*k.i/(1+k.i))
+      s2 <- -sum(Zsave[,j]*k.i/(1+k.i))
 
     grad[k.beta+k.alpha+j] <- s1 + s2
 
